# Settings for netauth.node42.org

from settings.core import *


# MAIN APPLICATION
INSTALLED_APPS += ('main', )

# NETAUTH_SETTINGS
AUTHENTICATION_BACKENDS = ( 'django.contrib.auth.backends.ModelBackend', 'netauth.auth.NetBackend', )
INSTALLED_APPS += ('netauth', )

YANDEX_APPLICATION_ID = "51a38f59a8cf4e96b7635d33a5b37bfe"

FACEBOOK_APPLICATION_ID = "124962940900708"
FACEBOOK_APPLICATION_SECRET = "626e88ccb61ff09ed2416b9f0b93cf08"

TWITTER_CONSUMER_KEY = "vD7tukEla4lJzBPr4BU4hw"
TWITTER_CONSUMER_SECRET = "Uf5KDzDQ8pugSx7502i1GMlj19SAmdw64jFc7nKA"

VKONTAKTE_APPLICATION_ID = "2045136"
VKONTAKTE_APPLICATION_SECRET = "Fj9ROpKBcYSE2MkEr5zo"
